Crate pozk_utils Copy item path Source aa_wallet This module was auto-generated with ethers-rs Abigen.
More information at: https://github.com/gakonst/ethers-rs controller This module was auto-generated with ethers-rs Abigen.
More information at: https://github.com/gakonst/ethers-rs epoch This module was auto-generated with ethers-rs Abigen.
More information at: https://github.com/gakonst/ethers-rs prover This module was auto-generated with ethers-rs Abigen.
More information at: https://github.com/gakonst/ethers-rs reward This module was auto-generated with ethers-rs Abigen.
More information at: https://github.com/gakonst/ethers-rs stake This module was auto-generated with ethers-rs Abigen.
More information at: https://github.com/gakonst/ethers-rs task This module was auto-generated with ethers-rs Abigen.
More information at: https://github.com/gakonst/ethers-rs token This module was auto-generated with ethers-rs Abigen.
More information at: https://github.com/gakonst/ethers-rs vesting This module was auto-generated with ethers-rs Abigen.
More information at: https://github.com/gakonst/ethers-rs AAWallet AcceptCall Container type for all input parameters for the accept function with signature accept(uint256,address,string) and selector 0x98ec820a AcceptTaskFilter AddAllowlistCall Container type for all input parameters for the addAllowlist function with signature addAllowlist(address[],uint256[]) and selector 0xa1ac1bed AddAllowlistFilter AddCall Container type for all input parameters for the add function with signature add(address) and selector 0x0a3b0a4f AddDaoCall Container type for all input parameters for the addDao function with signature addDao(address,bool) and selector 0x0f9d06fe AddDaoFilter AddUnstakingCall Container type for all input parameters for the addUnstaking function with signature addUnstaking(address,uint256) and selector 0xdd4d01a4 AddUnstakingFilter AddressEmptyCode Custom Error type AddressEmptyCode with signature AddressEmptyCode(address) and selector 0x9996b315 AddressInsufficientBalance Custom Error type AddressInsufficientBalance with signature AddressInsufficientBalance(address) and selector 0xcd786059 AdjudicateCall Container type for all input parameters for the adjudicate function with signature adjudicate(uint256,uint256,uint256,bool) and selector 0xd1553c1f AdjudicateTaskFilter AllowanceCall Container type for all input parameters for the allowance function with signature allowance(address,address) and selector 0xdd62ed3e AllowanceReturn Container type for all return fields from the allowance function with signature allowance(address,address) and selector 0xdd62ed3e AllowlistCall Container type for all input parameters for the allowlist function with signature allowlist(address) and selector 0xa7cd52cb AllowlistReturn Container type for all return fields from the allowlist function with signature allowlist(address) and selector 0xa7cd52cb AlphaDenominatorCall Container type for all input parameters for the alphaDenominator function with signature alphaDenominator() and selector 0xce853613 AlphaDenominatorReturn Container type for all return fields from the alphaDenominator function with signature alphaDenominator() and selector 0xce853613 AlphaFilter AlphaNumeratorCall Container type for all input parameters for the alphaNumerator function with signature alphaNumerator() and selector 0x7ef82070 AlphaNumeratorReturn Container type for all return fields from the alphaNumerator function with signature alphaNumerator() and selector 0x7ef82070 ApprovalFilter ApproveCall Container type for all input parameters for the approve function with signature approve(address,uint256) and selector 0x095ea7b3 ApproveCall Container type for all input parameters for the approve function with signature approve(address,bool,bool) and selector 0xc45d21ae ApproveForRewardCall Container type for all input parameters for the approveForReward function with signature approveForReward(uint256) and selector 0xa69171b9 ApproveProverFilter ApproveReturn Container type for all return fields from the approve function with signature approve(address,uint256) and selector 0x095ea7b3 BalanceOfCall Container type for all input parameters for the balanceOf function with signature balanceOf(address) and selector 0x70a08231 BalanceOfReturn Container type for all return fields from the balanceOf function with signature balanceOf(address) and selector 0x70a08231 BetaDenominatorCall Container type for all input parameters for the betaDenominator function with signature betaDenominator() and selector 0xc82bf452 BetaDenominatorReturn Container type for all return fields from the betaDenominator function with signature betaDenominator() and selector 0xc82bf452 BetaFilter BetaNumeratorCall Container type for all input parameters for the betaNumerator function with signature betaNumerator() and selector 0x0e55b80b BetaNumeratorReturn Container type for all return fields from the betaNumerator function with signature betaNumerator() and selector 0x0e55b80b ChangeControllerFilter CheckCall Container type for all input parameters for the check function with signature check(address,address) and selector 0xb3154db0 CheckReturn Container type for all return fields from the check function with signature check(address,address) and selector 0xb3154db0 ClaimCall Container type for all input parameters for the claim function with signature claim(address) and selector 0x1e83409a ClaimExtraProverRewardsCall Container type for all input parameters for the claimExtraProverRewards function with signature claimExtraProverRewards(address,uint256) and selector 0x87492e24 ClaimExtraProverRewardsFilter ClaimUnstakingFilter ClaimableCall Container type for all input parameters for the claimable function with signature claimable(address) and selector 0x402914f5 ClaimableReturn Container type for all return fields from the claimable function with signature claimable(address) and selector 0x402914f5 Controller CreateCall Container type for all input parameters for the create function with signature create(address,address,uint256,bytes,bytes) and selector 0x1bc12b58 CreateReturn Container type for all return fields from the create function with signature create(address,address,uint256,bytes,bytes) and selector 0x1bc12b58 CreateTaskFilter DaoCall Container type for all input parameters for the dao function with signature dao(address) and selector 0x22830af4 DaoReturn Container type for all return fields from the dao function with signature dao(address) and selector 0x22830af4 DecimalsCall Container type for all input parameters for the decimals function with signature decimals() and selector 0x313ce567 DecimalsReturn Container type for all return fields from the decimals function with signature decimals() and selector 0x313ce567 DepositExtraProverRewardsCall Container type for all input parameters for the depositExtraProverRewards function with signature depositExtraProverRewards(address,uint256,address,uint256) and selector 0x51e3bd06 DepositExtraProverRewardsFilter DisputeCall Container type for all input parameters for the dispute function with signature dispute(uint256) and selector 0x86d6282c DisputeDepositCall Container type for all input parameters for the disputeDeposit function with signature disputeDeposit() and selector 0x29e03ff1 DisputeDepositReturn Container type for all return fields from the disputeDeposit function with signature disputeDeposit() and selector 0x29e03ff1 DisputeTaskFilter ERC20InsufficientAllowance Custom Error type ERC20InsufficientAllowance with signature ERC20InsufficientAllowance(address,uint256,uint256) and selector 0xfb8f41b2 ERC20InsufficientBalance Custom Error type ERC20InsufficientBalance with signature ERC20InsufficientBalance(address,uint256,uint256) and selector 0xe450d38c ERC20InvalidApprover Custom Error type ERC20InvalidApprover with signature ERC20InvalidApprover(address) and selector 0xe602df05 ERC20InvalidReceiver Custom Error type ERC20InvalidReceiver with signature ERC20InvalidReceiver(address) and selector 0xec442f05 ERC20InvalidSender Custom Error type ERC20InvalidSender with signature ERC20InvalidSender(address) and selector 0x96c6fd1e ERC20InvalidSpender Custom Error type ERC20InvalidSpender with signature ERC20InvalidSpender(address) and selector 0x94280d62 Epoch ExtraProverRewardsCall Container type for all input parameters for the extraProverRewards function with signature extraProverRewards(address,uint256) and selector 0x07ac56a2 ExtraProverRewardsReturn Container type for all return fields from the extraProverRewards function with signature extraProverRewards(address,uint256) and selector 0x07ac56a2 FailedInnerCall Custom Error type FailedInnerCall with signature FailedInnerCall() and selector 0x1425ea42 FunctionCallCall Container type for all input parameters for the functionCall function with signature functionCall(address,address,uint256,bytes,uint8,bytes32,bytes32) and selector 0x5f5e685e FunctionMulticallCall Container type for all input parameters for the functionMulticall function with signature functionMulticall((address,address,uint256,bytes)[],uint8,bytes32,bytes32) and selector 0xdd4ebfc7 GammaDenominatorCall Container type for all input parameters for the gammaDenominator function with signature gammaDenominator() and selector 0x037d1ba4 GammaDenominatorReturn Container type for all return fields from the gammaDenominator function with signature gammaDenominator() and selector 0x037d1ba4 GammaFilter GammaNumeratorCall Container type for all input parameters for the gammaNumerator function with signature gammaNumerator() and selector 0xae75379d GammaNumeratorReturn Container type for all return fields from the gammaNumerator function with signature gammaNumerator() and selector 0xae75379d GetAndUpdateCall Container type for all input parameters for the getAndUpdate function with signature getAndUpdate() and selector 0x18ca80a7 GetAndUpdateReturn Container type for all return fields from the getAndUpdate function with signature getAndUpdate() and selector 0x18ca80a7 GetCall Container type for all input parameters for the get function with signature get() and selector 0x6d4ce63c GetReturn Container type for all return fields from the get function with signature get() and selector 0x6d4ce63c HeightCall Container type for all input parameters for the height function with signature height() and selector 0x0ef26743 HeightReturn Container type for all return fields from the height function with signature height() and selector 0x0ef26743 InitializeCall Container type for all input parameters for the initialize function with signature initialize(address,uint256) and selector 0xcd6dc687 InitializeCall Container type for all input parameters for the initialize function with signature initialize(address,uint256) and selector 0xcd6dc687 InitializeCall Container type for all input parameters for the initialize function with signature initialize(address) and selector 0xc4d66de8 InitializeCall Container type for all input parameters for the initialize function with signature initialize(address,uint256) and selector 0xcd6dc687 InitializeCall Container type for all input parameters for the initialize function with signature initialize(address,uint256) and selector 0xcd6dc687 InitializeCall Container type for all input parameters for the initialize function with signature initialize(address,int256,int256,int256,int256,int256,int256,uint256,uint256,uint256) and selector 0x9b1aa3bf InitializeCall Container type for all input parameters for the initialize function with signature initialize(address) and selector 0xc4d66de8 InitializedFilter InitializedFilter InitializedFilter InitializedFilter InitializedFilter InitializedFilter InitializedFilter InvalidInitialization Custom Error type InvalidInitialization with signature InvalidInitialization() and selector 0xf92ee8a9 InvalidInitialization Custom Error type InvalidInitialization with signature InvalidInitialization() and selector 0xf92ee8a9 InvalidInitialization Custom Error type InvalidInitialization with signature InvalidInitialization() and selector 0xf92ee8a9 InvalidInitialization Custom Error type InvalidInitialization with signature InvalidInitialization() and selector 0xf92ee8a9 InvalidInitialization Custom Error type InvalidInitialization with signature InvalidInitialization() and selector 0xf92ee8a9 InvalidInitialization Custom Error type InvalidInitialization with signature InvalidInitialization() and selector 0xf92ee8a9 InvalidInitialization Custom Error type InvalidInitialization with signature InvalidInitialization() and selector 0xf92ee8a9 IsDaoCall Container type for all input parameters for the isDao function with signature isDao(address) and selector 0x1f9d8a60 IsDaoReturn Container type for all return fields from the isDao function with signature isDao(address) and selector 0x1f9d8a60 IsMinerCall Container type for all input parameters for the isMiner function with signature isMiner(address,address) and selector 0x43c6c395 IsMinerReturn Container type for all return fields from the isMiner function with signature isMiner(address,address) and selector 0x43c6c395 IsProverCall Container type for all input parameters for the isProver function with signature isProver(address) and selector 0x0a245924 IsProverReturn Container type for all return fields from the isProver function with signature isProver(address) and selector 0x0a245924 MaintenanceCall Container type for all input parameters for the maintenance function with signature maintenance() and selector 0x6c376cc5 MaintenanceReturn Container type for all return fields from the maintenance function with signature maintenance() and selector 0x6c376cc5 MessageItem MessageItem(address,address,uint256,bytes)MinStakeAmountCall Container type for all input parameters for the minStakeAmount function with signature minStakeAmount() and selector 0xf1887684 MinStakeAmountReturn Container type for all return fields from the minStakeAmount function with signature minStakeAmount() and selector 0xf1887684 MineCall Container type for all input parameters for the mine function with signature mine(uint256) and selector 0x4d474898 MineReturn Container type for all return fields from the mine function with signature mine(uint256) and selector 0x4d474898 MinerBatchCollectCall Container type for all input parameters for the minerBatchCollect function with signature minerBatchCollect(uint256,address) and selector 0x38db6813 MinerCall Container type for all input parameters for the miner function with signature miner(address) and selector 0xd45a7e2e MinerCollectCall Container type for all input parameters for the minerCollect function with signature minerCollect(uint256,address,address) and selector 0x816e64b6 MinerCollectFilter MinerLaborFilter MinerMaxPerCall Container type for all input parameters for the minerMaxPer function with signature minerMaxPer() and selector 0xb853822e MinerMaxPerReturn Container type for all return fields from the minerMaxPer function with signature minerMaxPer() and selector 0xb853822e MinerMinPerCall Container type for all input parameters for the minerMinPer function with signature minerMinPer() and selector 0x8f661eea MinerMinPerReturn Container type for all return fields from the minerMinPer function with signature minerMinPer() and selector 0x8f661eea MinerPlayerPerFilter MinerReturn Container type for all return fields from the miner function with signature miner(address) and selector 0xd45a7e2e MinerSlashStakingCall Container type for all input parameters for the minerSlashStaking function with signature minerSlashStaking(address,address,address,uint256) and selector 0xf3e405b8 MinerStakeCall Container type for all input parameters for the minerStake function with signature minerStake(address,uint256) and selector 0xaf4c0a3c MinerStakeChangeFilter MinerStakeForCall Container type for all input parameters for the minerStakeFor function with signature minerStakeFor(address,address,uint256) and selector 0xec9b6369 MinerStakingCall Container type for all input parameters for the minerStaking function with signature minerStaking(address,address) and selector 0x9a0179b5 MinerStakingReturn Container type for all return fields from the minerStaking function with signature minerStaking(address,address) and selector 0x9a0179b5 MinerTestCall Container type for all input parameters for the minerTest function with signature minerTest(uint256,bytes,bytes) and selector 0x68313797 MinerTestCancelCall Container type for all input parameters for the minerTestCancel function with signature minerTestCancel(uint256) and selector 0x4b3336ae MinerTestCancelFilter MinerTestCreateFilter MinerTestRequireFilter MinerTestSubmitCall Container type for all input parameters for the minerTestSubmit function with signature minerTestSubmit(uint256,bool,bytes) and selector 0x2731c9a6 MinerTestSubmitFilter MinerTotalStakingCall Container type for all input parameters for the minerTotalStaking function with signature minerTotalStaking(address) and selector 0xb8fcbd05 MinerTotalStakingReturn Container type for all return fields from the minerTotalStaking function with signature minerTotalStaking(address) and selector 0xb8fcbd05 MinerTransferStakingCall Container type for all input parameters for the minerTransferStaking function with signature minerTransferStaking(address,address,uint256) and selector 0x4bf4b9cf MinerUnstakeCall Container type for all input parameters for the minerUnstake function with signature minerUnstake(address,uint256) and selector 0xca18b14b MinersTotalCall Container type for all input parameters for the minersTotal function with signature minersTotal() and selector 0x03875e65 MinersTotalReturn Container type for all return fields from the minersTotal function with signature minersTotal() and selector 0x03875e65 NameCall Container type for all input parameters for the name function with signature name() and selector 0x06fdde03 NameReturn Container type for all return fields from the name function with signature name() and selector 0x06fdde03 NetworkModeCall Container type for all input parameters for the networkMode function with signature networkMode() and selector 0x83583383 NetworkModeReturn Container type for all return fields from the networkMode function with signature networkMode() and selector 0x83583383 NewEpochFilter NewMineRewardFilter NextIdCall Container type for all input parameters for the nextId function with signature nextId() and selector 0x61b8ce8c NextIdReturn Container type for all return fields from the nextId function with signature nextId() and selector 0x61b8ce8c NonceCall Container type for all input parameters for the nonce function with signature nonce() and selector 0xaffed0e0 NonceReturn Container type for all return fields from the nonce function with signature nonce() and selector 0xaffed0e0 NotInitializing Custom Error type NotInitializing with signature NotInitializing() and selector 0xd7e6bcf8 NotInitializing Custom Error type NotInitializing with signature NotInitializing() and selector 0xd7e6bcf8 NotInitializing Custom Error type NotInitializing with signature NotInitializing() and selector 0xd7e6bcf8 NotInitializing Custom Error type NotInitializing with signature NotInitializing() and selector 0xd7e6bcf8 NotInitializing Custom Error type NotInitializing with signature NotInitializing() and selector 0xd7e6bcf8 NotInitializing Custom Error type NotInitializing with signature NotInitializing() and selector 0xd7e6bcf8 NotInitializing Custom Error type NotInitializing with signature NotInitializing() and selector 0xd7e6bcf8 OvertimeCall Container type for all input parameters for the overtime function with signature overtime(address) and selector 0xe73ea685 OvertimeReturn Container type for all return fields from the overtime function with signature overtime(address) and selector 0xe73ea685 OwnableInvalidOwner Custom Error type OwnableInvalidOwner with signature OwnableInvalidOwner(address) and selector 0x1e4fbdf7 OwnableInvalidOwner Custom Error type OwnableInvalidOwner with signature OwnableInvalidOwner(address) and selector 0x1e4fbdf7 OwnableInvalidOwner Custom Error type OwnableInvalidOwner with signature OwnableInvalidOwner(address) and selector 0x1e4fbdf7 OwnableInvalidOwner Custom Error type OwnableInvalidOwner with signature OwnableInvalidOwner(address) and selector 0x1e4fbdf7 OwnableInvalidOwner Custom Error type OwnableInvalidOwner with signature OwnableInvalidOwner(address) and selector 0x1e4fbdf7 OwnableInvalidOwner Custom Error type OwnableInvalidOwner with signature OwnableInvalidOwner(address) and selector 0x1e4fbdf7 OwnableInvalidOwner Custom Error type OwnableInvalidOwner with signature OwnableInvalidOwner(address) and selector 0x1e4fbdf7 OwnableUnauthorizedAccount Custom Error type OwnableUnauthorizedAccount with signature OwnableUnauthorizedAccount(address) and selector 0x118cdaa7 OwnableUnauthorizedAccount Custom Error type OwnableUnauthorizedAccount with signature OwnableUnauthorizedAccount(address) and selector 0x118cdaa7 OwnableUnauthorizedAccount Custom Error type OwnableUnauthorizedAccount with signature OwnableUnauthorizedAccount(address) and selector 0x118cdaa7 OwnableUnauthorizedAccount Custom Error type OwnableUnauthorizedAccount with signature OwnableUnauthorizedAccount(address) and selector 0x118cdaa7 OwnableUnauthorizedAccount Custom Error type OwnableUnauthorizedAccount with signature OwnableUnauthorizedAccount(address) and selector 0x118cdaa7 OwnableUnauthorizedAccount Custom Error type OwnableUnauthorizedAccount with signature OwnableUnauthorizedAccount(address) and selector 0x118cdaa7 OwnableUnauthorizedAccount Custom Error type OwnableUnauthorizedAccount with signature OwnableUnauthorizedAccount(address) and selector 0x118cdaa7 OwnerCall Container type for all input parameters for the owner function with signature owner() and selector 0x8da5cb5b OwnerCall Container type for all input parameters for the owner function with signature owner() and selector 0x8da5cb5b OwnerCall Container type for all input parameters for the owner function with signature owner() and selector 0x8da5cb5b OwnerCall Container type for all input parameters for the owner function with signature owner() and selector 0x8da5cb5b OwnerCall Container type for all input parameters for the owner function with signature owner() and selector 0x8da5cb5b OwnerCall Container type for all input parameters for the owner function with signature owner() and selector 0x8da5cb5b OwnerCall Container type for all input parameters for the owner function with signature owner() and selector 0x8da5cb5b OwnerCall Container type for all input parameters for the owner function with signature owner() and selector 0x8da5cb5b OwnerReturn Container type for all return fields from the owner function with signature owner() and selector 0x8da5cb5b OwnerReturn Container type for all return fields from the owner function with signature owner() and selector 0x8da5cb5b OwnerReturn Container type for all return fields from the owner function with signature owner() and selector 0x8da5cb5b OwnerReturn Container type for all return fields from the owner function with signature owner() and selector 0x8da5cb5b OwnerReturn Container type for all return fields from the owner function with signature owner() and selector 0x8da5cb5b OwnerReturn Container type for all return fields from the owner function with signature owner() and selector 0x8da5cb5b OwnerReturn Container type for all return fields from the owner function with signature owner() and selector 0x8da5cb5b OwnerReturn Container type for all return fields from the owner function with signature owner() and selector 0x8da5cb5b OwnerWithProverCall Container type for all input parameters for the owner function with signature owner(address) and selector 0x666e1b39 OwnerWithProverReturn Container type for all return fields from the owner function with signature owner(address) and selector 0x666e1b39 OwnershipTransferredFilter OwnershipTransferredFilter OwnershipTransferredFilter OwnershipTransferredFilter OwnershipTransferredFilter OwnershipTransferredFilter OwnershipTransferredFilter PeriodCall Container type for all input parameters for the period function with signature period() and selector 0xef78d4fd PeriodReturn Container type for all return fields from the period function with signature period() and selector 0xef78d4fd PlayerBatchCollectCall Container type for all input parameters for the playerBatchCollect function with signature playerBatchCollect(uint256,address) and selector 0x2c260d30 PlayerCollectCall Container type for all input parameters for the playerCollect function with signature playerCollect(uint256,address,address) and selector 0x4473b0df PlayerCollectFilter PlayerLaborFilter PlayerMaxNumCall Container type for all input parameters for the playerMaxNum function with signature playerMaxNum() and selector 0x9ac08fcb PlayerMaxNumReturn Container type for all return fields from the playerMaxNum function with signature playerMaxNum() and selector 0x9ac08fcb PlayerStakeCall Container type for all input parameters for the playerStake function with signature playerStake(uint256) and selector 0x9a4309c9 PlayerStakeChangeFilter PlayerStakeForCall Container type for all input parameters for the playerStakeFor function with signature playerStakeFor(address,uint256) and selector 0x68d0ce26 PlayerStakingCall Container type for all input parameters for the playerStaking function with signature playerStaking(address) and selector 0x4818bb7b PlayerStakingReturn Container type for all return fields from the playerStaking function with signature playerStaking(address) and selector 0x4818bb7b PlayerTotalStakingCall Container type for all input parameters for the playerTotalStaking function with signature playerTotalStaking() and selector 0xb7552af8 PlayerTotalStakingReturn Container type for all return fields from the playerTotalStaking function with signature playerTotalStaking() and selector 0xb7552af8 PlayerUnstakeCall Container type for all input parameters for the playerUnstake function with signature playerUnstake(uint256) and selector 0x7776464c Prover ProverStakeCall Container type for all input parameters for the proverStake function with signature proverStake(address,uint256) and selector 0x12343bd7 ProverStakeChangeFilter ProverStakingCall Container type for all input parameters for the proverStaking function with signature proverStaking(address,address) and selector 0x23761b6b ProverStakingReturn Container type for all return fields from the proverStaking function with signature proverStaking(address,address) and selector 0x23761b6b ProverTotalStakingCall Container type for all input parameters for the proverTotalStaking function with signature proverTotalStaking(address) and selector 0xa2c91a76 ProverTotalStakingReturn Container type for all return fields from the proverTotalStaking function with signature proverTotalStaking(address) and selector 0xa2c91a76 ProverUnstakeCall Container type for all input parameters for the proverUnstake function with signature proverUnstake(address,uint256) and selector 0x11eefdb4 ProxyCall Container type for all input parameters for the proxy function with signature proxy(address[],address[],address[]) and selector 0x6c65926d ProxyListCall Container type for all input parameters for the proxyList function with signature proxyList(address) and selector 0x57e3a3f1 ProxyListReturn Container type for all return fields from the proxyList function with signature proxyList(address) and selector 0x57e3a3f1 ProxyTaskFilter RegisterCall Container type for all input parameters for the register function with signature register(address,uint256,uint256,uint256,address) and selector 0x665b3a8f RegisterProverFilter RemoveCall Container type for all input parameters for the remove function with signature remove(address) and selector 0x29092d0e RenounceOwnershipCall Container type for all input parameters for the renounceOwnership function with signature renounceOwnership() and selector 0x715018a6 RenounceOwnershipCall Container type for all input parameters for the renounceOwnership function with signature renounceOwnership() and selector 0x715018a6 RenounceOwnershipCall Container type for all input parameters for the renounceOwnership function with signature renounceOwnership() and selector 0x715018a6 RenounceOwnershipCall Container type for all input parameters for the renounceOwnership function with signature renounceOwnership() and selector 0x715018a6 RenounceOwnershipCall Container type for all input parameters for the renounceOwnership function with signature renounceOwnership() and selector 0x715018a6 RenounceOwnershipCall Container type for all input parameters for the renounceOwnership function with signature renounceOwnership() and selector 0x715018a6 RenounceOwnershipCall Container type for all input parameters for the renounceOwnership function with signature renounceOwnership() and selector 0x715018a6 Reward SafeERC20FailedOperation Custom Error type SafeERC20FailedOperation with signature SafeERC20FailedOperation(address) and selector 0x5274afe7 SetAddressesCall Container type for all input parameters for the setAddresses function with signature setAddresses(address) and selector 0x81d3c435 SetAddressesCall Container type for all input parameters for the setAddresses function with signature setAddresses(address) and selector 0x81d3c435 SetAddressesCall Container type for all input parameters for the setAddresses function with signature setAddresses(address) and selector 0x81d3c435 SetAddressesCall Container type for all input parameters for the setAddresses function with signature setAddresses(address) and selector 0x81d3c435 SetAddressesCall Container type for all input parameters for the setAddresses function with signature setAddresses(address) and selector 0x81d3c435 SetAddressesCall Container type for all input parameters for the setAddresses function with signature setAddresses(address) and selector 0x81d3c435 SetAddressesCall Container type for all input parameters for the setAddresses function with signature setAddresses(address) and selector 0x81d3c435 SetAlphaCall Container type for all input parameters for the setAlpha function with signature setAlpha(int256,int256) and selector 0xe76cdb21 SetBetaCall Container type for all input parameters for the setBeta function with signature setBeta(int256,int256) and selector 0x63719ad7 SetDisputeDepositCall Container type for all input parameters for the setDisputeDeposit function with signature setDisputeDeposit(uint256) and selector 0x16972978 SetGammaCall Container type for all input parameters for the setGamma function with signature setGamma(int256,int256) and selector 0x6b187e0b SetMaintenanceCall Container type for all input parameters for the setMaintenance function with signature setMaintenance(bool) and selector 0x612f2f37 SetMinStakeAmountCall Container type for all input parameters for the setMinStakeAmount function with signature setMinStakeAmount(uint256) and selector 0xeb4af045 SetMineRewardCall Container type for all input parameters for the setMineReward function with signature setMineReward(uint256) and selector 0xf47807fb SetMinerAmountCall Container type for all input parameters for the setMinerAmount function with signature setMinerAmount(address[],uint256[],uint256[]) and selector 0x83468e75 SetMinerPlayerPerCall Container type for all input parameters for the setMinerPlayerPer function with signature setMinerPlayerPer(uint256,uint256,uint256) and selector 0x1d1a9ba6 SetNetworkModeCall Container type for all input parameters for the setNetworkMode function with signature setNetworkMode(uint8) and selector 0x77cdb5c4 SetPeriodCall Container type for all input parameters for the setPeriod function with signature setPeriod(uint256) and selector 0x0f3a9f65 SetProxyListCall Container type for all input parameters for the setProxyList function with signature setProxyList(address,bool) and selector 0x289e7a63 Stake StartTimeCall Container type for all input parameters for the startTime function with signature startTime() and selector 0x78e97925 StartTimeReturn Container type for all return fields from the startTime function with signature startTime() and selector 0x78e97925 StopCall Container type for all input parameters for the stop function with signature stop(address) and selector 0x656cb0bc StopProverFilter SubAllowlistFilter SubmitCall Container type for all input parameters for the submit function with signature submit(uint256,bytes) and selector 0xd1a2eab2 SubmitTaskFilter SymbolCall Container type for all input parameters for the symbol function with signature symbol() and selector 0x95d89b41 SymbolReturn Container type for all return fields from the symbol function with signature symbol() and selector 0x95d89b41 Task TasksCall Container type for all input parameters for the tasks function with signature tasks(uint256) and selector 0x8d977672 TasksResultsCall Container type for all input parameters for the tasksResults function with signature tasksResults(bytes32) and selector 0x713633c6 TasksResultsReturn Container type for all return fields from the tasksResults function with signature tasksResults(bytes32) and selector 0x713633c6 TasksReturn Container type for all return fields from the tasks function with signature tasks(uint256) and selector 0x8d977672 Token TotalSupplyCall Container type for all input parameters for the totalSupply function with signature totalSupply() and selector 0x18160ddd TotalSupplyReturn Container type for all return fields from the totalSupply function with signature totalSupply() and selector 0x18160ddd TotalWorkCall Container type for all input parameters for the totalWork function with signature totalWork() and selector 0xbbaca84f TotalWorkReturn Container type for all return fields from the totalWork function with signature totalWork() and selector 0xbbaca84f TransferCall Container type for all input parameters for the transfer function with signature transfer(address,uint256) and selector 0xa9059cbb TransferFilter TransferFromCall Container type for all input parameters for the transferFrom function with signature transferFrom(address,address,uint256) and selector 0x23b872dd TransferFromReturn Container type for all return fields from the transferFrom function with signature transferFrom(address,address,uint256) and selector 0x23b872dd TransferOwnershipCall Container type for all input parameters for the transferOwnership function with signature transferOwnership(address) and selector 0xf2fde38b TransferOwnershipCall Container type for all input parameters for the transferOwnership function with signature transferOwnership(address) and selector 0xf2fde38b TransferOwnershipCall Container type for all input parameters for the transferOwnership function with signature transferOwnership(address) and selector 0xf2fde38b TransferOwnershipCall Container type for all input parameters for the transferOwnership function with signature transferOwnership(address) and selector 0xf2fde38b TransferOwnershipCall Container type for all input parameters for the transferOwnership function with signature transferOwnership(address) and selector 0xf2fde38b TransferOwnershipCall Container type for all input parameters for the transferOwnership function with signature transferOwnership(address) and selector 0xf2fde38b TransferOwnershipCall Container type for all input parameters for the transferOwnership function with signature transferOwnership(address) and selector 0xf2fde38b TransferProverFilter TransferProverOwnerCall Container type for all input parameters for the transferProverOwner function with signature transferProverOwner(address,address) and selector 0xd90182b1 TransferReturn Container type for all return fields from the transfer function with signature transfer(address,uint256) and selector 0xa9059cbb UnregisterCall Container type for all input parameters for the unregister function with signature unregister(address) and selector 0x2ec2c246 UpgradeCall Container type for all input parameters for the upgrade function with signature upgrade(address,uint256,uint256,uint256,address) and selector 0x2a3d2f49 UpgradeProverFilter VerifierCall Container type for all input parameters for the verifier function with signature verifier(address) and selector 0x809f3bc4 VerifierReturn Container type for all return fields from the verifier function with signature verifier(address) and selector 0x809f3bc4 VersionCall Container type for all input parameters for the version function with signature version(address) and selector 0x767cb5bf VersionReturn Container type for all return fields from the version function with signature version(address) and selector 0x767cb5bf Vesting WorkCall Container type for all input parameters for the work function with signature work(address) and selector 0x36df7ea5 WorkCall Container type for all input parameters for the work function with signature work(address,address,address) and selector 0x5bd5483d WorkReturn Container type for all return fields from the work function with signature work(address) and selector 0x36df7ea5 AAWalletCalls Container type for all of the contract’s call BinaryMessage ControllerCalls Container type for all of the contract’s call ControllerErrors Container type for all of the contract’s custom errors ControllerEvents Container type for all of the contract’s events EpochCalls Container type for all of the contract’s call EpochErrors Container type for all of the contract’s custom errors EpochEvents Container type for all of the contract’s events ProverCalls Container type for all of the contract’s call ProverErrors Container type for all of the contract’s custom errors ProverEvents Container type for all of the contract’s events RewardCalls Container type for all of the contract’s call RewardErrors Container type for all of the contract’s custom errors RewardEvents Container type for all of the contract’s events ServiceMessage StakeCalls Container type for all of the contract’s call StakeErrors Container type for all of the contract’s custom errors StakeEvents Container type for all of the contract’s events TaskCalls Container type for all of the contract’s call TaskErrors Container type for all of the contract’s custom errors TaskEvents Container type for all of the contract’s events TextMessage TokenCalls Container type for all of the contract’s call TokenErrors Container type for all of the contract’s custom errors TokenEvents Container type for all of the contract’s events VestingCalls Container type for all of the contract’s call VestingErrors Container type for all of the contract’s custom errors VestingEvents Container type for all of the contract’s events AAWALLET_ABI The parsed JSON ABI of the contract. CONTROLLER_ABI The parsed JSON ABI of the contract. EPOCH_ABI The parsed JSON ABI of the contract. PROVER_ABI The parsed JSON ABI of the contract. REWARD_ABI The parsed JSON ABI of the contract. STAKE_ABI The parsed JSON ABI of the contract. TASK_ABI The parsed JSON ABI of the contract. TOKEN_ABI The parsed JSON ABI of the contract. VESTING_ABI The parsed JSON ABI of the contract. check_task_proxy_list check_zero_gas contract_address convert_task_to_connect_api create_zero_gas download_input download_input_with_uri get_task_api init_path_and_server new_providers new_service_channel new_signer parse_task_input pozk_metrics_url pozk_rpc_url pozk_zero_gas_url read_task_input read_task_proof remove_task_input upload_proof upload_proof_with_uri write_task_input write_task_proof zero_gas Address DefaultProvider DefaultSigner