pub struct ClaimableReturn(pub U256);Expand description
Container type for all return fields from the claimable function with signature claimable(address) and selector 0x402914f5
Tuple Fields
0: U256Trait Implementations
Sourceimpl AbiDecode for ClaimableReturn
impl AbiDecode for ClaimableReturn
Sourceimpl AbiEncode for ClaimableReturn
impl AbiEncode for ClaimableReturn
Sourceimpl AbiType for ClaimableReturn
impl AbiType for ClaimableReturn
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for ClaimableReturn
impl Clone for ClaimableReturn
Sourcefn clone(&self) -> ClaimableReturn
fn clone(&self) -> ClaimableReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClaimableReturn
impl Debug for ClaimableReturn
Sourceimpl Default for ClaimableReturn
impl Default for ClaimableReturn
Sourcefn default() -> ClaimableReturn
fn default() -> ClaimableReturn
Returns the “default value” for a type. Read more
Sourceimpl Hash for ClaimableReturn
impl Hash for ClaimableReturn
Sourceimpl PartialEq for ClaimableReturn
impl PartialEq for ClaimableReturn
Sourceimpl Tokenizable for ClaimableReturn
impl Tokenizable for ClaimableReturn
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for ClaimableReturn
impl Eq for ClaimableReturn
impl StructuralPartialEq for ClaimableReturn
impl TokenizableItem for ClaimableReturn