pub struct AddDaoCall {
pub account: Address,
pub ok: bool,
}Expand description
Container type for all input parameters for the addDao function with signature addDao(address,bool) and selector 0x0f9d06fe
Fields
account: Addressok: boolTrait Implementations
Sourceimpl AbiDecode for AddDaoCall
impl AbiDecode for AddDaoCall
Sourceimpl AbiEncode for AddDaoCall
impl AbiEncode for AddDaoCall
Sourceimpl AbiType for AddDaoCall
impl AbiType for AddDaoCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for AddDaoCall
impl Clone for AddDaoCall
Sourcefn clone(&self) -> AddDaoCall
fn clone(&self) -> AddDaoCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddDaoCall
impl Debug for AddDaoCall
Sourceimpl Default for AddDaoCall
impl Default for AddDaoCall
Sourcefn default() -> AddDaoCall
fn default() -> AddDaoCall
Returns the “default value” for a type. Read more
Sourceimpl Display for AddDaoCall
impl Display for AddDaoCall
Sourceimpl EthCall for AddDaoCall
impl EthCall for AddDaoCall
Sourceimpl From<AddDaoCall> for EpochCalls
impl From<AddDaoCall> for EpochCalls
Sourcefn from(value: AddDaoCall) -> Self
fn from(value: AddDaoCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for AddDaoCall
impl Hash for AddDaoCall
Sourceimpl PartialEq for AddDaoCall
impl PartialEq for AddDaoCall
Sourceimpl Tokenizable for AddDaoCall
impl Tokenizable for AddDaoCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for AddDaoCall
impl Eq for AddDaoCall
impl StructuralPartialEq for AddDaoCall
impl TokenizableItem for AddDaoCall