pub struct AddDaoFilter {
pub account: Address,
pub ok: bool,
}Fields
account: Addressok: boolTrait Implementations
Sourceimpl AbiType for AddDaoFilter
impl AbiType for AddDaoFilter
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for AddDaoFilter
impl Clone for AddDaoFilter
Sourcefn clone(&self) -> AddDaoFilter
fn clone(&self) -> AddDaoFilter
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddDaoFilter
impl Debug for AddDaoFilter
Sourceimpl Default for AddDaoFilter
impl Default for AddDaoFilter
Sourcefn default() -> AddDaoFilter
fn default() -> AddDaoFilter
Returns the “default value” for a type. Read more
Sourceimpl Display for AddDaoFilter
impl Display for AddDaoFilter
Sourceimpl EthEvent for AddDaoFilter
impl EthEvent for AddDaoFilter
Sourcefn signature() -> H256
fn signature() -> H256
Retrieves the signature for the event this data corresponds to.
This signature is the Keccak-256 hash of the ABI signature of
this event.
Sourcefn abi_signature() -> Cow<'static, str>
fn abi_signature() -> Cow<'static, str>
Retrieves the ABI signature for the event this data corresponds
to.
Sourcefn decode_log(log: &RawLog) -> Result<Self, Error>where
Self: Sized,
fn decode_log(log: &RawLog) -> Result<Self, Error>where
Self: Sized,
Decodes an Ethereum
RawLog into an instance of the type.Sourcefn is_anonymous() -> bool
fn is_anonymous() -> bool
Returns true if this is an anonymous event
Sourceimpl From<AddDaoFilter> for EpochEvents
impl From<AddDaoFilter> for EpochEvents
Sourcefn from(value: AddDaoFilter) -> Self
fn from(value: AddDaoFilter) -> Self
Converts to this type from the input type.
Sourceimpl Hash for AddDaoFilter
impl Hash for AddDaoFilter
Sourceimpl PartialEq for AddDaoFilter
impl PartialEq for AddDaoFilter
Sourceimpl Tokenizable for AddDaoFilter
impl Tokenizable for AddDaoFilter
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for AddDaoFilter
impl Eq for AddDaoFilter
impl StructuralPartialEq for AddDaoFilter
impl TokenizableItem for AddDaoFilter