pub struct AddUnstakingCall {
pub account: Address,
pub amount: U256,
}Expand description
Container type for all input parameters for the addUnstaking function with signature addUnstaking(address,uint256) and selector 0xdd4d01a4
Fields
account: Addressamount: U256Trait Implementations
Sourceimpl AbiDecode for AddUnstakingCall
impl AbiDecode for AddUnstakingCall
Sourceimpl AbiEncode for AddUnstakingCall
impl AbiEncode for AddUnstakingCall
Sourceimpl AbiType for AddUnstakingCall
impl AbiType for AddUnstakingCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for AddUnstakingCall
impl Clone for AddUnstakingCall
Sourcefn clone(&self) -> AddUnstakingCall
fn clone(&self) -> AddUnstakingCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddUnstakingCall
impl Debug for AddUnstakingCall
Sourceimpl Default for AddUnstakingCall
impl Default for AddUnstakingCall
Sourcefn default() -> AddUnstakingCall
fn default() -> AddUnstakingCall
Returns the “default value” for a type. Read more
Sourceimpl Display for AddUnstakingCall
impl Display for AddUnstakingCall
Sourceimpl EthCall for AddUnstakingCall
impl EthCall for AddUnstakingCall
Sourceimpl From<AddUnstakingCall> for StakeCalls
impl From<AddUnstakingCall> for StakeCalls
Sourcefn from(value: AddUnstakingCall) -> Self
fn from(value: AddUnstakingCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for AddUnstakingCall
impl Hash for AddUnstakingCall
Sourceimpl PartialEq for AddUnstakingCall
impl PartialEq for AddUnstakingCall
Sourceimpl Tokenizable for AddUnstakingCall
impl Tokenizable for AddUnstakingCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for AddUnstakingCall
impl Eq for AddUnstakingCall
impl StructuralPartialEq for AddUnstakingCall
impl TokenizableItem for AddUnstakingCall