pub struct AllowlistReturn(pub U256);Expand description
Container type for all return fields from the allowlist function with signature allowlist(address) and selector 0xa7cd52cb
Tuple Fields
0: U256Trait Implementations
Sourceimpl AbiDecode for AllowlistReturn
impl AbiDecode for AllowlistReturn
Sourceimpl AbiEncode for AllowlistReturn
impl AbiEncode for AllowlistReturn
Sourceimpl AbiType for AllowlistReturn
impl AbiType for AllowlistReturn
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for AllowlistReturn
impl Clone for AllowlistReturn
Sourcefn clone(&self) -> AllowlistReturn
fn clone(&self) -> AllowlistReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AllowlistReturn
impl Debug for AllowlistReturn
Sourceimpl Default for AllowlistReturn
impl Default for AllowlistReturn
Sourcefn default() -> AllowlistReturn
fn default() -> AllowlistReturn
Returns the “default value” for a type. Read more
Sourceimpl Hash for AllowlistReturn
impl Hash for AllowlistReturn
Sourceimpl PartialEq for AllowlistReturn
impl PartialEq for AllowlistReturn
Sourceimpl Tokenizable for AllowlistReturn
impl Tokenizable for AllowlistReturn
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for AllowlistReturn
impl Eq for AllowlistReturn
impl StructuralPartialEq for AllowlistReturn
impl TokenizableItem for AllowlistReturn