pub struct ClaimExtraProverRewardsCall {
pub prover: Address,
pub epoch: U256,
}Expand description
Container type for all input parameters for the claimExtraProverRewards function with signature claimExtraProverRewards(address,uint256) and selector 0x87492e24
Fields
prover: Addressepoch: U256Trait Implementations
Sourceimpl AbiType for ClaimExtraProverRewardsCall
impl AbiType for ClaimExtraProverRewardsCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for ClaimExtraProverRewardsCall
impl Clone for ClaimExtraProverRewardsCall
Sourcefn clone(&self) -> ClaimExtraProverRewardsCall
fn clone(&self) -> ClaimExtraProverRewardsCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClaimExtraProverRewardsCall
impl Debug for ClaimExtraProverRewardsCall
Sourceimpl Default for ClaimExtraProverRewardsCall
impl Default for ClaimExtraProverRewardsCall
Sourcefn default() -> ClaimExtraProverRewardsCall
fn default() -> ClaimExtraProverRewardsCall
Returns the “default value” for a type. Read more
Sourceimpl From<ClaimExtraProverRewardsCall> for RewardCalls
impl From<ClaimExtraProverRewardsCall> for RewardCalls
Sourcefn from(value: ClaimExtraProverRewardsCall) -> Self
fn from(value: ClaimExtraProverRewardsCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for ClaimExtraProverRewardsCall
impl Hash for ClaimExtraProverRewardsCall
Sourceimpl Tokenizable for ClaimExtraProverRewardsCall
impl Tokenizable for ClaimExtraProverRewardsCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for ClaimExtraProverRewardsCall
impl Eq for ClaimExtraProverRewardsCall
impl StructuralPartialEq for ClaimExtraProverRewardsCall
impl TokenizableItem for ClaimExtraProverRewardsCall