pub struct ClaimExtraProverRewardsFilter {
pub prover: Address,
pub epoch: U256,
pub remain: U256,
}Fields
prover: Addressepoch: U256remain: U256Trait Implementations
Sourceimpl AbiType for ClaimExtraProverRewardsFilter
impl AbiType for ClaimExtraProverRewardsFilter
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for ClaimExtraProverRewardsFilter
impl Clone for ClaimExtraProverRewardsFilter
Sourcefn clone(&self) -> ClaimExtraProverRewardsFilter
fn clone(&self) -> ClaimExtraProverRewardsFilter
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ClaimExtraProverRewardsFilter
impl Default for ClaimExtraProverRewardsFilter
Sourcefn default() -> ClaimExtraProverRewardsFilter
fn default() -> ClaimExtraProverRewardsFilter
Returns the “default value” for a type. Read more
Sourceimpl EthEvent for ClaimExtraProverRewardsFilter
impl EthEvent for ClaimExtraProverRewardsFilter
Sourcefn signature() -> H256
fn signature() -> H256
Retrieves the signature for the event this data corresponds to.
This signature is the Keccak-256 hash of the ABI signature of
this event.
Sourcefn abi_signature() -> Cow<'static, str>
fn abi_signature() -> Cow<'static, str>
Retrieves the ABI signature for the event this data corresponds
to.
Sourcefn decode_log(log: &RawLog) -> Result<Self, Error>where
Self: Sized,
fn decode_log(log: &RawLog) -> Result<Self, Error>where
Self: Sized,
Decodes an Ethereum
RawLog into an instance of the type.Sourcefn is_anonymous() -> bool
fn is_anonymous() -> bool
Returns true if this is an anonymous event
Sourceimpl From<ClaimExtraProverRewardsFilter> for RewardEvents
impl From<ClaimExtraProverRewardsFilter> for RewardEvents
Sourcefn from(value: ClaimExtraProverRewardsFilter) -> Self
fn from(value: ClaimExtraProverRewardsFilter) -> Self
Converts to this type from the input type.
Sourceimpl Hash for ClaimExtraProverRewardsFilter
impl Hash for ClaimExtraProverRewardsFilter
Sourceimpl PartialEq for ClaimExtraProverRewardsFilter
impl PartialEq for ClaimExtraProverRewardsFilter
Sourcefn eq(&self, other: &ClaimExtraProverRewardsFilter) -> bool
fn eq(&self, other: &ClaimExtraProverRewardsFilter) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Tokenizable for ClaimExtraProverRewardsFilter
impl Tokenizable for ClaimExtraProverRewardsFilter
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for ClaimExtraProverRewardsFilter
impl Eq for ClaimExtraProverRewardsFilter
impl StructuralPartialEq for ClaimExtraProverRewardsFilter
impl TokenizableItem for ClaimExtraProverRewardsFilter