pub struct FunctionCallCall {
pub from: Address,
pub to: Address,
pub value: U256,
pub data: Bytes,
pub v: u8,
pub r: [u8; 32],
pub s: [u8; 32],
}Expand description
Container type for all input parameters for the functionCall function with signature functionCall(address,address,uint256,bytes,uint8,bytes32,bytes32) and selector 0x5f5e685e
Fields
from: Addressto: Addressvalue: U256data: Bytesv: u8r: [u8; 32]s: [u8; 32]Trait Implementations
Sourceimpl AbiDecode for FunctionCallCall
impl AbiDecode for FunctionCallCall
Sourceimpl AbiEncode for FunctionCallCall
impl AbiEncode for FunctionCallCall
Sourceimpl AbiType for FunctionCallCall
impl AbiType for FunctionCallCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for FunctionCallCall
impl Clone for FunctionCallCall
Sourcefn clone(&self) -> FunctionCallCall
fn clone(&self) -> FunctionCallCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FunctionCallCall
impl Debug for FunctionCallCall
Sourceimpl Default for FunctionCallCall
impl Default for FunctionCallCall
Sourcefn default() -> FunctionCallCall
fn default() -> FunctionCallCall
Returns the “default value” for a type. Read more
Sourceimpl Display for FunctionCallCall
impl Display for FunctionCallCall
Sourceimpl EthCall for FunctionCallCall
impl EthCall for FunctionCallCall
Sourceimpl From<FunctionCallCall> for AAWalletCalls
impl From<FunctionCallCall> for AAWalletCalls
Sourcefn from(value: FunctionCallCall) -> Self
fn from(value: FunctionCallCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for FunctionCallCall
impl Hash for FunctionCallCall
Sourceimpl PartialEq for FunctionCallCall
impl PartialEq for FunctionCallCall
Sourceimpl Tokenizable for FunctionCallCall
impl Tokenizable for FunctionCallCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for FunctionCallCall
impl Eq for FunctionCallCall
impl StructuralPartialEq for FunctionCallCall
impl TokenizableItem for FunctionCallCall