pub struct FunctionMulticallCall {
pub items: Vec<MessageItem>,
pub v: u8,
pub r: [u8; 32],
pub s: [u8; 32],
}Expand description
Container type for all input parameters for the functionMulticall function with signature functionMulticall((address,address,uint256,bytes)[],uint8,bytes32,bytes32) and selector 0xdd4ebfc7
Fields
items: Vec<MessageItem>v: u8r: [u8; 32]s: [u8; 32]Trait Implementations
Sourceimpl AbiDecode for FunctionMulticallCall
impl AbiDecode for FunctionMulticallCall
Sourceimpl AbiEncode for FunctionMulticallCall
impl AbiEncode for FunctionMulticallCall
Sourceimpl AbiType for FunctionMulticallCall
impl AbiType for FunctionMulticallCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for FunctionMulticallCall
impl Clone for FunctionMulticallCall
Sourcefn clone(&self) -> FunctionMulticallCall
fn clone(&self) -> FunctionMulticallCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FunctionMulticallCall
impl Debug for FunctionMulticallCall
Sourceimpl Default for FunctionMulticallCall
impl Default for FunctionMulticallCall
Sourcefn default() -> FunctionMulticallCall
fn default() -> FunctionMulticallCall
Returns the “default value” for a type. Read more
Sourceimpl Display for FunctionMulticallCall
impl Display for FunctionMulticallCall
Sourceimpl EthCall for FunctionMulticallCall
impl EthCall for FunctionMulticallCall
Sourceimpl From<FunctionMulticallCall> for AAWalletCalls
impl From<FunctionMulticallCall> for AAWalletCalls
Sourcefn from(value: FunctionMulticallCall) -> Self
fn from(value: FunctionMulticallCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for FunctionMulticallCall
impl Hash for FunctionMulticallCall
Sourceimpl PartialEq for FunctionMulticallCall
impl PartialEq for FunctionMulticallCall
Sourceimpl Tokenizable for FunctionMulticallCall
impl Tokenizable for FunctionMulticallCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for FunctionMulticallCall
impl Eq for FunctionMulticallCall
impl StructuralPartialEq for FunctionMulticallCall
impl TokenizableItem for FunctionMulticallCall