pub struct GetAndUpdateReturn(pub U256);Expand description
Container type for all return fields from the getAndUpdate function with signature getAndUpdate() and selector 0x18ca80a7
Tuple Fields
0: U256Trait Implementations
Sourceimpl AbiDecode for GetAndUpdateReturn
impl AbiDecode for GetAndUpdateReturn
Sourceimpl AbiEncode for GetAndUpdateReturn
impl AbiEncode for GetAndUpdateReturn
Sourceimpl AbiType for GetAndUpdateReturn
impl AbiType for GetAndUpdateReturn
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for GetAndUpdateReturn
impl Clone for GetAndUpdateReturn
Sourcefn clone(&self) -> GetAndUpdateReturn
fn clone(&self) -> GetAndUpdateReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetAndUpdateReturn
impl Debug for GetAndUpdateReturn
Sourceimpl Default for GetAndUpdateReturn
impl Default for GetAndUpdateReturn
Sourcefn default() -> GetAndUpdateReturn
fn default() -> GetAndUpdateReturn
Returns the “default value” for a type. Read more
Sourceimpl Hash for GetAndUpdateReturn
impl Hash for GetAndUpdateReturn
Sourceimpl PartialEq for GetAndUpdateReturn
impl PartialEq for GetAndUpdateReturn
Sourceimpl Tokenizable for GetAndUpdateReturn
impl Tokenizable for GetAndUpdateReturn
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for GetAndUpdateReturn
impl Eq for GetAndUpdateReturn
impl StructuralPartialEq for GetAndUpdateReturn
impl TokenizableItem for GetAndUpdateReturn