pub struct HeightReturn(pub U256);Expand description
Container type for all return fields from the height function with signature height() and selector 0x0ef26743
Tuple Fields
0: U256Trait Implementations
Sourceimpl AbiDecode for HeightReturn
impl AbiDecode for HeightReturn
Sourceimpl AbiEncode for HeightReturn
impl AbiEncode for HeightReturn
Sourceimpl AbiType for HeightReturn
impl AbiType for HeightReturn
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for HeightReturn
impl Clone for HeightReturn
Sourcefn clone(&self) -> HeightReturn
fn clone(&self) -> HeightReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HeightReturn
impl Debug for HeightReturn
Sourceimpl Default for HeightReturn
impl Default for HeightReturn
Sourcefn default() -> HeightReturn
fn default() -> HeightReturn
Returns the “default value” for a type. Read more
Sourceimpl Hash for HeightReturn
impl Hash for HeightReturn
Sourceimpl PartialEq for HeightReturn
impl PartialEq for HeightReturn
Sourceimpl Tokenizable for HeightReturn
impl Tokenizable for HeightReturn
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for HeightReturn
impl Eq for HeightReturn
impl StructuralPartialEq for HeightReturn
impl TokenizableItem for HeightReturn