pub struct IsProverCall {
pub prover: Address,
}Expand description
Container type for all input parameters for the isProver function with signature isProver(address) and selector 0x0a245924
Fields
prover: AddressTrait Implementations
Sourceimpl AbiDecode for IsProverCall
impl AbiDecode for IsProverCall
Sourceimpl AbiEncode for IsProverCall
impl AbiEncode for IsProverCall
Sourceimpl AbiType for IsProverCall
impl AbiType for IsProverCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for IsProverCall
impl Clone for IsProverCall
Sourcefn clone(&self) -> IsProverCall
fn clone(&self) -> IsProverCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IsProverCall
impl Debug for IsProverCall
Sourceimpl Default for IsProverCall
impl Default for IsProverCall
Sourcefn default() -> IsProverCall
fn default() -> IsProverCall
Returns the “default value” for a type. Read more
Sourceimpl Display for IsProverCall
impl Display for IsProverCall
Sourceimpl EthCall for IsProverCall
impl EthCall for IsProverCall
Sourceimpl From<IsProverCall> for ProverCalls
impl From<IsProverCall> for ProverCalls
Sourcefn from(value: IsProverCall) -> Self
fn from(value: IsProverCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for IsProverCall
impl Hash for IsProverCall
Sourceimpl PartialEq for IsProverCall
impl PartialEq for IsProverCall
Sourceimpl Tokenizable for IsProverCall
impl Tokenizable for IsProverCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for IsProverCall
impl Eq for IsProverCall
impl StructuralPartialEq for IsProverCall
impl TokenizableItem for IsProverCall