pub struct MinerPlayerPerFilter {
pub miner_max_per: U256,
pub miner_min_per: U256,
pub player_max_num: U256,
}Fields
miner_max_per: U256miner_min_per: U256player_max_num: U256Trait Implementations
Sourceimpl AbiType for MinerPlayerPerFilter
impl AbiType for MinerPlayerPerFilter
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for MinerPlayerPerFilter
impl Clone for MinerPlayerPerFilter
Sourcefn clone(&self) -> MinerPlayerPerFilter
fn clone(&self) -> MinerPlayerPerFilter
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MinerPlayerPerFilter
impl Debug for MinerPlayerPerFilter
Sourceimpl Default for MinerPlayerPerFilter
impl Default for MinerPlayerPerFilter
Sourcefn default() -> MinerPlayerPerFilter
fn default() -> MinerPlayerPerFilter
Returns the “default value” for a type. Read more
Sourceimpl Display for MinerPlayerPerFilter
impl Display for MinerPlayerPerFilter
Sourceimpl EthEvent for MinerPlayerPerFilter
impl EthEvent for MinerPlayerPerFilter
Sourcefn signature() -> H256
fn signature() -> H256
Retrieves the signature for the event this data corresponds to.
This signature is the Keccak-256 hash of the ABI signature of
this event.
Sourcefn abi_signature() -> Cow<'static, str>
fn abi_signature() -> Cow<'static, str>
Retrieves the ABI signature for the event this data corresponds
to.
Sourcefn decode_log(log: &RawLog) -> Result<Self, Error>where
Self: Sized,
fn decode_log(log: &RawLog) -> Result<Self, Error>where
Self: Sized,
Decodes an Ethereum
RawLog into an instance of the type.Sourcefn is_anonymous() -> bool
fn is_anonymous() -> bool
Returns true if this is an anonymous event
Sourceimpl From<MinerPlayerPerFilter> for RewardEvents
impl From<MinerPlayerPerFilter> for RewardEvents
Sourcefn from(value: MinerPlayerPerFilter) -> Self
fn from(value: MinerPlayerPerFilter) -> Self
Converts to this type from the input type.
Sourceimpl Hash for MinerPlayerPerFilter
impl Hash for MinerPlayerPerFilter
Sourceimpl PartialEq for MinerPlayerPerFilter
impl PartialEq for MinerPlayerPerFilter
Sourceimpl Tokenizable for MinerPlayerPerFilter
impl Tokenizable for MinerPlayerPerFilter
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for MinerPlayerPerFilter
impl Eq for MinerPlayerPerFilter
impl StructuralPartialEq for MinerPlayerPerFilter
impl TokenizableItem for MinerPlayerPerFilter