pub struct MinerTestCall {
pub id: U256,
pub inputs: Bytes,
pub publics: Bytes,
}Expand description
Container type for all input parameters for the minerTest function with signature minerTest(uint256,bytes,bytes) and selector 0x68313797
Fields
id: U256inputs: Bytespublics: BytesTrait Implementations
Sourceimpl AbiDecode for MinerTestCall
impl AbiDecode for MinerTestCall
Sourceimpl AbiEncode for MinerTestCall
impl AbiEncode for MinerTestCall
Sourceimpl AbiType for MinerTestCall
impl AbiType for MinerTestCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for MinerTestCall
impl Clone for MinerTestCall
Sourcefn clone(&self) -> MinerTestCall
fn clone(&self) -> MinerTestCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MinerTestCall
impl Debug for MinerTestCall
Sourceimpl Default for MinerTestCall
impl Default for MinerTestCall
Sourcefn default() -> MinerTestCall
fn default() -> MinerTestCall
Returns the “default value” for a type. Read more
Sourceimpl Display for MinerTestCall
impl Display for MinerTestCall
Sourceimpl EthCall for MinerTestCall
impl EthCall for MinerTestCall
Sourceimpl From<MinerTestCall> for StakeCalls
impl From<MinerTestCall> for StakeCalls
Sourcefn from(value: MinerTestCall) -> Self
fn from(value: MinerTestCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for MinerTestCall
impl Hash for MinerTestCall
Sourceimpl PartialEq for MinerTestCall
impl PartialEq for MinerTestCall
Sourceimpl Tokenizable for MinerTestCall
impl Tokenizable for MinerTestCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for MinerTestCall
impl Eq for MinerTestCall
impl StructuralPartialEq for MinerTestCall
impl TokenizableItem for MinerTestCall