pub struct PeriodReturn(pub U256);Expand description
Container type for all return fields from the period function with signature period() and selector 0xef78d4fd
Tuple Fields
0: U256Trait Implementations
Sourceimpl AbiDecode for PeriodReturn
impl AbiDecode for PeriodReturn
Sourceimpl AbiEncode for PeriodReturn
impl AbiEncode for PeriodReturn
Sourceimpl AbiType for PeriodReturn
impl AbiType for PeriodReturn
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for PeriodReturn
impl Clone for PeriodReturn
Sourcefn clone(&self) -> PeriodReturn
fn clone(&self) -> PeriodReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PeriodReturn
impl Debug for PeriodReturn
Sourceimpl Default for PeriodReturn
impl Default for PeriodReturn
Sourcefn default() -> PeriodReturn
fn default() -> PeriodReturn
Returns the “default value” for a type. Read more
Sourceimpl Hash for PeriodReturn
impl Hash for PeriodReturn
Sourceimpl PartialEq for PeriodReturn
impl PartialEq for PeriodReturn
Sourceimpl Tokenizable for PeriodReturn
impl Tokenizable for PeriodReturn
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for PeriodReturn
impl Eq for PeriodReturn
impl StructuralPartialEq for PeriodReturn
impl TokenizableItem for PeriodReturn