pub struct PlayerCollectCall {
pub epoch: U256,
pub prover: Address,
pub player: Address,
}Expand description
Container type for all input parameters for the playerCollect function with signature playerCollect(uint256,address,address) and selector 0x4473b0df
Fields
epoch: U256prover: Addressplayer: AddressTrait Implementations
Sourceimpl AbiDecode for PlayerCollectCall
impl AbiDecode for PlayerCollectCall
Sourceimpl AbiEncode for PlayerCollectCall
impl AbiEncode for PlayerCollectCall
Sourceimpl AbiType for PlayerCollectCall
impl AbiType for PlayerCollectCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for PlayerCollectCall
impl Clone for PlayerCollectCall
Sourcefn clone(&self) -> PlayerCollectCall
fn clone(&self) -> PlayerCollectCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlayerCollectCall
impl Debug for PlayerCollectCall
Sourceimpl Default for PlayerCollectCall
impl Default for PlayerCollectCall
Sourcefn default() -> PlayerCollectCall
fn default() -> PlayerCollectCall
Returns the “default value” for a type. Read more
Sourceimpl Display for PlayerCollectCall
impl Display for PlayerCollectCall
Sourceimpl EthCall for PlayerCollectCall
impl EthCall for PlayerCollectCall
Sourceimpl From<PlayerCollectCall> for RewardCalls
impl From<PlayerCollectCall> for RewardCalls
Sourcefn from(value: PlayerCollectCall) -> Self
fn from(value: PlayerCollectCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for PlayerCollectCall
impl Hash for PlayerCollectCall
Sourceimpl PartialEq for PlayerCollectCall
impl PartialEq for PlayerCollectCall
Sourceimpl Tokenizable for PlayerCollectCall
impl Tokenizable for PlayerCollectCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for PlayerCollectCall
impl Eq for PlayerCollectCall
impl StructuralPartialEq for PlayerCollectCall
impl TokenizableItem for PlayerCollectCall