pub struct PlayerStakeCall {
pub amount: U256,
}Expand description
Container type for all input parameters for the playerStake function with signature playerStake(uint256) and selector 0x9a4309c9
Fields
amount: U256Trait Implementations
Sourceimpl AbiDecode for PlayerStakeCall
impl AbiDecode for PlayerStakeCall
Sourceimpl AbiEncode for PlayerStakeCall
impl AbiEncode for PlayerStakeCall
Sourceimpl AbiType for PlayerStakeCall
impl AbiType for PlayerStakeCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for PlayerStakeCall
impl Clone for PlayerStakeCall
Sourcefn clone(&self) -> PlayerStakeCall
fn clone(&self) -> PlayerStakeCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlayerStakeCall
impl Debug for PlayerStakeCall
Sourceimpl Default for PlayerStakeCall
impl Default for PlayerStakeCall
Sourcefn default() -> PlayerStakeCall
fn default() -> PlayerStakeCall
Returns the “default value” for a type. Read more
Sourceimpl Display for PlayerStakeCall
impl Display for PlayerStakeCall
Sourceimpl EthCall for PlayerStakeCall
impl EthCall for PlayerStakeCall
Sourceimpl From<PlayerStakeCall> for StakeCalls
impl From<PlayerStakeCall> for StakeCalls
Sourcefn from(value: PlayerStakeCall) -> Self
fn from(value: PlayerStakeCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for PlayerStakeCall
impl Hash for PlayerStakeCall
Sourceimpl PartialEq for PlayerStakeCall
impl PartialEq for PlayerStakeCall
Sourceimpl Tokenizable for PlayerStakeCall
impl Tokenizable for PlayerStakeCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for PlayerStakeCall
impl Eq for PlayerStakeCall
impl StructuralPartialEq for PlayerStakeCall
impl TokenizableItem for PlayerStakeCall