pub struct PlayerStakingCall {
pub account: Address,
}Expand description
Container type for all input parameters for the playerStaking function with signature playerStaking(address) and selector 0x4818bb7b
Fields
account: AddressTrait Implementations
Sourceimpl AbiDecode for PlayerStakingCall
impl AbiDecode for PlayerStakingCall
Sourceimpl AbiEncode for PlayerStakingCall
impl AbiEncode for PlayerStakingCall
Sourceimpl AbiType for PlayerStakingCall
impl AbiType for PlayerStakingCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for PlayerStakingCall
impl Clone for PlayerStakingCall
Sourcefn clone(&self) -> PlayerStakingCall
fn clone(&self) -> PlayerStakingCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlayerStakingCall
impl Debug for PlayerStakingCall
Sourceimpl Default for PlayerStakingCall
impl Default for PlayerStakingCall
Sourcefn default() -> PlayerStakingCall
fn default() -> PlayerStakingCall
Returns the “default value” for a type. Read more
Sourceimpl Display for PlayerStakingCall
impl Display for PlayerStakingCall
Sourceimpl EthCall for PlayerStakingCall
impl EthCall for PlayerStakingCall
Sourceimpl From<PlayerStakingCall> for StakeCalls
impl From<PlayerStakingCall> for StakeCalls
Sourcefn from(value: PlayerStakingCall) -> Self
fn from(value: PlayerStakingCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for PlayerStakingCall
impl Hash for PlayerStakingCall
Sourceimpl PartialEq for PlayerStakingCall
impl PartialEq for PlayerStakingCall
Sourceimpl Tokenizable for PlayerStakingCall
impl Tokenizable for PlayerStakingCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for PlayerStakingCall
impl Eq for PlayerStakingCall
impl StructuralPartialEq for PlayerStakingCall
impl TokenizableItem for PlayerStakingCall