pub struct ProxyListReturn(pub bool);Expand description
Container type for all return fields from the proxyList function with signature proxyList(address) and selector 0x57e3a3f1
Tuple Fields
0: boolTrait Implementations
Sourceimpl AbiDecode for ProxyListReturn
impl AbiDecode for ProxyListReturn
Sourceimpl AbiEncode for ProxyListReturn
impl AbiEncode for ProxyListReturn
Sourceimpl AbiType for ProxyListReturn
impl AbiType for ProxyListReturn
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for ProxyListReturn
impl Clone for ProxyListReturn
Sourcefn clone(&self) -> ProxyListReturn
fn clone(&self) -> ProxyListReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProxyListReturn
impl Debug for ProxyListReturn
Sourceimpl Default for ProxyListReturn
impl Default for ProxyListReturn
Sourcefn default() -> ProxyListReturn
fn default() -> ProxyListReturn
Returns the “default value” for a type. Read more
Sourceimpl Hash for ProxyListReturn
impl Hash for ProxyListReturn
Sourceimpl PartialEq for ProxyListReturn
impl PartialEq for ProxyListReturn
Sourceimpl Tokenizable for ProxyListReturn
impl Tokenizable for ProxyListReturn
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for ProxyListReturn
impl Eq for ProxyListReturn
impl StructuralPartialEq for ProxyListReturn
impl TokenizableItem for ProxyListReturn