pub struct RegisterCall {
pub prover: Address,
pub work: U256,
pub version: U256,
pub overtime: U256,
pub verifier: Address,
}Expand description
Container type for all input parameters for the register function with signature register(address,uint256,uint256,uint256,address) and selector 0x665b3a8f
Fields
prover: Addresswork: U256version: U256overtime: U256verifier: AddressTrait Implementations
Sourceimpl AbiDecode for RegisterCall
impl AbiDecode for RegisterCall
Sourceimpl AbiEncode for RegisterCall
impl AbiEncode for RegisterCall
Sourceimpl AbiType for RegisterCall
impl AbiType for RegisterCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for RegisterCall
impl Clone for RegisterCall
Sourcefn clone(&self) -> RegisterCall
fn clone(&self) -> RegisterCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RegisterCall
impl Debug for RegisterCall
Sourceimpl Default for RegisterCall
impl Default for RegisterCall
Sourcefn default() -> RegisterCall
fn default() -> RegisterCall
Returns the “default value” for a type. Read more
Sourceimpl Display for RegisterCall
impl Display for RegisterCall
Sourceimpl EthCall for RegisterCall
impl EthCall for RegisterCall
Sourceimpl From<RegisterCall> for ProverCalls
impl From<RegisterCall> for ProverCalls
Sourcefn from(value: RegisterCall) -> Self
fn from(value: RegisterCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for RegisterCall
impl Hash for RegisterCall
Sourceimpl PartialEq for RegisterCall
impl PartialEq for RegisterCall
Sourceimpl Tokenizable for RegisterCall
impl Tokenizable for RegisterCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for RegisterCall
impl Eq for RegisterCall
impl StructuralPartialEq for RegisterCall
impl TokenizableItem for RegisterCall