pub struct SetAlphaCall {
pub alpha_numerator: I256,
pub alpha_denominator: I256,
}Expand description
Container type for all input parameters for the setAlpha function with signature setAlpha(int256,int256) and selector 0xe76cdb21
Fields
alpha_numerator: I256alpha_denominator: I256Trait Implementations
Sourceimpl AbiDecode for SetAlphaCall
impl AbiDecode for SetAlphaCall
Sourceimpl AbiEncode for SetAlphaCall
impl AbiEncode for SetAlphaCall
Sourceimpl AbiType for SetAlphaCall
impl AbiType for SetAlphaCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for SetAlphaCall
impl Clone for SetAlphaCall
Sourcefn clone(&self) -> SetAlphaCall
fn clone(&self) -> SetAlphaCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetAlphaCall
impl Debug for SetAlphaCall
Sourceimpl Default for SetAlphaCall
impl Default for SetAlphaCall
Sourcefn default() -> SetAlphaCall
fn default() -> SetAlphaCall
Returns the “default value” for a type. Read more
Sourceimpl Display for SetAlphaCall
impl Display for SetAlphaCall
Sourceimpl EthCall for SetAlphaCall
impl EthCall for SetAlphaCall
Sourceimpl From<SetAlphaCall> for RewardCalls
impl From<SetAlphaCall> for RewardCalls
Sourcefn from(value: SetAlphaCall) -> Self
fn from(value: SetAlphaCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for SetAlphaCall
impl Hash for SetAlphaCall
Sourceimpl PartialEq for SetAlphaCall
impl PartialEq for SetAlphaCall
Sourceimpl Tokenizable for SetAlphaCall
impl Tokenizable for SetAlphaCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for SetAlphaCall
impl Eq for SetAlphaCall
impl StructuralPartialEq for SetAlphaCall
impl TokenizableItem for SetAlphaCall