pub struct SetMaintenanceCall {
pub open: bool,
}Expand description
Container type for all input parameters for the setMaintenance function with signature setMaintenance(bool) and selector 0x612f2f37
Fields
open: boolTrait Implementations
Sourceimpl AbiDecode for SetMaintenanceCall
impl AbiDecode for SetMaintenanceCall
Sourceimpl AbiEncode for SetMaintenanceCall
impl AbiEncode for SetMaintenanceCall
Sourceimpl AbiType for SetMaintenanceCall
impl AbiType for SetMaintenanceCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for SetMaintenanceCall
impl Clone for SetMaintenanceCall
Sourcefn clone(&self) -> SetMaintenanceCall
fn clone(&self) -> SetMaintenanceCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetMaintenanceCall
impl Debug for SetMaintenanceCall
Sourceimpl Default for SetMaintenanceCall
impl Default for SetMaintenanceCall
Sourcefn default() -> SetMaintenanceCall
fn default() -> SetMaintenanceCall
Returns the “default value” for a type. Read more
Sourceimpl Display for SetMaintenanceCall
impl Display for SetMaintenanceCall
Sourceimpl EthCall for SetMaintenanceCall
impl EthCall for SetMaintenanceCall
Sourceimpl From<SetMaintenanceCall> for EpochCalls
impl From<SetMaintenanceCall> for EpochCalls
Sourcefn from(value: SetMaintenanceCall) -> Self
fn from(value: SetMaintenanceCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for SetMaintenanceCall
impl Hash for SetMaintenanceCall
Sourceimpl PartialEq for SetMaintenanceCall
impl PartialEq for SetMaintenanceCall
Sourceimpl Tokenizable for SetMaintenanceCall
impl Tokenizable for SetMaintenanceCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for SetMaintenanceCall
impl Eq for SetMaintenanceCall
impl StructuralPartialEq for SetMaintenanceCall
impl TokenizableItem for SetMaintenanceCall