pub struct SetMinerAmountCall {
pub miners: Vec<Address>,
pub amounts: Vec<U256>,
pub ends: Vec<U256>,
}Expand description
Container type for all input parameters for the setMinerAmount function with signature setMinerAmount(address[],uint256[],uint256[]) and selector 0x83468e75
Fields
miners: Vec<Address>amounts: Vec<U256>ends: Vec<U256>Trait Implementations
Sourceimpl AbiDecode for SetMinerAmountCall
impl AbiDecode for SetMinerAmountCall
Sourceimpl AbiEncode for SetMinerAmountCall
impl AbiEncode for SetMinerAmountCall
Sourceimpl AbiType for SetMinerAmountCall
impl AbiType for SetMinerAmountCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for SetMinerAmountCall
impl Clone for SetMinerAmountCall
Sourcefn clone(&self) -> SetMinerAmountCall
fn clone(&self) -> SetMinerAmountCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetMinerAmountCall
impl Debug for SetMinerAmountCall
Sourceimpl Default for SetMinerAmountCall
impl Default for SetMinerAmountCall
Sourcefn default() -> SetMinerAmountCall
fn default() -> SetMinerAmountCall
Returns the “default value” for a type. Read more
Sourceimpl Display for SetMinerAmountCall
impl Display for SetMinerAmountCall
Sourceimpl EthCall for SetMinerAmountCall
impl EthCall for SetMinerAmountCall
Sourceimpl From<SetMinerAmountCall> for VestingCalls
impl From<SetMinerAmountCall> for VestingCalls
Sourcefn from(value: SetMinerAmountCall) -> Self
fn from(value: SetMinerAmountCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for SetMinerAmountCall
impl Hash for SetMinerAmountCall
Sourceimpl PartialEq for SetMinerAmountCall
impl PartialEq for SetMinerAmountCall
Sourceimpl Tokenizable for SetMinerAmountCall
impl Tokenizable for SetMinerAmountCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for SetMinerAmountCall
impl Eq for SetMinerAmountCall
impl StructuralPartialEq for SetMinerAmountCall
impl TokenizableItem for SetMinerAmountCall