pub struct SetNetworkModeCall {
pub mode: u8,
}Expand description
Container type for all input parameters for the setNetworkMode function with signature setNetworkMode(uint8) and selector 0x77cdb5c4
Fields
mode: u8Trait Implementations
Sourceimpl AbiDecode for SetNetworkModeCall
impl AbiDecode for SetNetworkModeCall
Sourceimpl AbiEncode for SetNetworkModeCall
impl AbiEncode for SetNetworkModeCall
Sourceimpl AbiType for SetNetworkModeCall
impl AbiType for SetNetworkModeCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for SetNetworkModeCall
impl Clone for SetNetworkModeCall
Sourcefn clone(&self) -> SetNetworkModeCall
fn clone(&self) -> SetNetworkModeCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetNetworkModeCall
impl Debug for SetNetworkModeCall
Sourceimpl Default for SetNetworkModeCall
impl Default for SetNetworkModeCall
Sourcefn default() -> SetNetworkModeCall
fn default() -> SetNetworkModeCall
Returns the “default value” for a type. Read more
Sourceimpl Display for SetNetworkModeCall
impl Display for SetNetworkModeCall
Sourceimpl EthCall for SetNetworkModeCall
impl EthCall for SetNetworkModeCall
Sourceimpl From<SetNetworkModeCall> for EpochCalls
impl From<SetNetworkModeCall> for EpochCalls
Sourcefn from(value: SetNetworkModeCall) -> Self
fn from(value: SetNetworkModeCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for SetNetworkModeCall
impl Hash for SetNetworkModeCall
Sourceimpl PartialEq for SetNetworkModeCall
impl PartialEq for SetNetworkModeCall
Sourceimpl Tokenizable for SetNetworkModeCall
impl Tokenizable for SetNetworkModeCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for SetNetworkModeCall
impl Eq for SetNetworkModeCall
impl StructuralPartialEq for SetNetworkModeCall
impl TokenizableItem for SetNetworkModeCall