pub struct TransferProverOwnerCall {
pub prover: Address,
pub owner: Address,
}Expand description
Container type for all input parameters for the transferProverOwner function with signature transferProverOwner(address,address) and selector 0xd90182b1
Fields
prover: Addressowner: AddressTrait Implementations
Sourceimpl AbiDecode for TransferProverOwnerCall
impl AbiDecode for TransferProverOwnerCall
Sourceimpl AbiEncode for TransferProverOwnerCall
impl AbiEncode for TransferProverOwnerCall
Sourceimpl AbiType for TransferProverOwnerCall
impl AbiType for TransferProverOwnerCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for TransferProverOwnerCall
impl Clone for TransferProverOwnerCall
Sourcefn clone(&self) -> TransferProverOwnerCall
fn clone(&self) -> TransferProverOwnerCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransferProverOwnerCall
impl Debug for TransferProverOwnerCall
Sourceimpl Default for TransferProverOwnerCall
impl Default for TransferProverOwnerCall
Sourcefn default() -> TransferProverOwnerCall
fn default() -> TransferProverOwnerCall
Returns the “default value” for a type. Read more
Sourceimpl Display for TransferProverOwnerCall
impl Display for TransferProverOwnerCall
Sourceimpl EthCall for TransferProverOwnerCall
impl EthCall for TransferProverOwnerCall
Sourceimpl From<TransferProverOwnerCall> for ProverCalls
impl From<TransferProverOwnerCall> for ProverCalls
Sourcefn from(value: TransferProverOwnerCall) -> Self
fn from(value: TransferProverOwnerCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for TransferProverOwnerCall
impl Hash for TransferProverOwnerCall
Sourceimpl PartialEq for TransferProverOwnerCall
impl PartialEq for TransferProverOwnerCall
Sourceimpl Tokenizable for TransferProverOwnerCall
impl Tokenizable for TransferProverOwnerCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for TransferProverOwnerCall
impl Eq for TransferProverOwnerCall
impl StructuralPartialEq for TransferProverOwnerCall
impl TokenizableItem for TransferProverOwnerCall