pub struct UpgradeCall {
pub prover: Address,
pub work: U256,
pub version: U256,
pub overtime: U256,
pub verifier: Address,
}Expand description
Container type for all input parameters for the upgrade function with signature upgrade(address,uint256,uint256,uint256,address) and selector 0x2a3d2f49
Fields
prover: Addresswork: U256version: U256overtime: U256verifier: AddressTrait Implementations
Sourceimpl AbiDecode for UpgradeCall
impl AbiDecode for UpgradeCall
Sourceimpl AbiEncode for UpgradeCall
impl AbiEncode for UpgradeCall
Sourceimpl AbiType for UpgradeCall
impl AbiType for UpgradeCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for UpgradeCall
impl Clone for UpgradeCall
Sourcefn clone(&self) -> UpgradeCall
fn clone(&self) -> UpgradeCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpgradeCall
impl Debug for UpgradeCall
Sourceimpl Default for UpgradeCall
impl Default for UpgradeCall
Sourcefn default() -> UpgradeCall
fn default() -> UpgradeCall
Returns the “default value” for a type. Read more
Sourceimpl Display for UpgradeCall
impl Display for UpgradeCall
Sourceimpl EthCall for UpgradeCall
impl EthCall for UpgradeCall
Sourceimpl From<UpgradeCall> for ProverCalls
impl From<UpgradeCall> for ProverCalls
Sourcefn from(value: UpgradeCall) -> Self
fn from(value: UpgradeCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for UpgradeCall
impl Hash for UpgradeCall
Sourceimpl PartialEq for UpgradeCall
impl PartialEq for UpgradeCall
Sourceimpl Tokenizable for UpgradeCall
impl Tokenizable for UpgradeCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for UpgradeCall
impl Eq for UpgradeCall
impl StructuralPartialEq for UpgradeCall
impl TokenizableItem for UpgradeCall