pub struct UpgradeProverFilter {
pub prover: Address,
pub work: U256,
pub version: U256,
pub overtime: U256,
pub verifier: Address,
pub name: String,
}Fields
prover: Addresswork: U256version: U256overtime: U256verifier: Addressname: StringTrait Implementations
Sourceimpl AbiType for UpgradeProverFilter
impl AbiType for UpgradeProverFilter
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for UpgradeProverFilter
impl Clone for UpgradeProverFilter
Sourcefn clone(&self) -> UpgradeProverFilter
fn clone(&self) -> UpgradeProverFilter
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpgradeProverFilter
impl Debug for UpgradeProverFilter
Sourceimpl Default for UpgradeProverFilter
impl Default for UpgradeProverFilter
Sourcefn default() -> UpgradeProverFilter
fn default() -> UpgradeProverFilter
Returns the “default value” for a type. Read more
Sourceimpl Display for UpgradeProverFilter
impl Display for UpgradeProverFilter
Sourceimpl EthEvent for UpgradeProverFilter
impl EthEvent for UpgradeProverFilter
Sourcefn signature() -> H256
fn signature() -> H256
Retrieves the signature for the event this data corresponds to.
This signature is the Keccak-256 hash of the ABI signature of
this event.
Sourcefn abi_signature() -> Cow<'static, str>
fn abi_signature() -> Cow<'static, str>
Retrieves the ABI signature for the event this data corresponds
to.
Sourcefn decode_log(log: &RawLog) -> Result<Self, Error>where
Self: Sized,
fn decode_log(log: &RawLog) -> Result<Self, Error>where
Self: Sized,
Decodes an Ethereum
RawLog into an instance of the type.Sourcefn is_anonymous() -> bool
fn is_anonymous() -> bool
Returns true if this is an anonymous event
Sourceimpl From<UpgradeProverFilter> for ProverEvents
impl From<UpgradeProverFilter> for ProverEvents
Sourcefn from(value: UpgradeProverFilter) -> Self
fn from(value: UpgradeProverFilter) -> Self
Converts to this type from the input type.
Sourceimpl Hash for UpgradeProverFilter
impl Hash for UpgradeProverFilter
Sourceimpl PartialEq for UpgradeProverFilter
impl PartialEq for UpgradeProverFilter
Sourceimpl Tokenizable for UpgradeProverFilter
impl Tokenizable for UpgradeProverFilter
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for UpgradeProverFilter
impl Eq for UpgradeProverFilter
impl StructuralPartialEq for UpgradeProverFilter
impl TokenizableItem for UpgradeProverFilter