pub struct VerifierCall {
pub prover: Address,
}Expand description
Container type for all input parameters for the verifier function with signature verifier(address) and selector 0x809f3bc4
Fields
prover: AddressTrait Implementations
Sourceimpl AbiDecode for VerifierCall
impl AbiDecode for VerifierCall
Sourceimpl AbiEncode for VerifierCall
impl AbiEncode for VerifierCall
Sourceimpl AbiType for VerifierCall
impl AbiType for VerifierCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for VerifierCall
impl Clone for VerifierCall
Sourcefn clone(&self) -> VerifierCall
fn clone(&self) -> VerifierCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerifierCall
impl Debug for VerifierCall
Sourceimpl Default for VerifierCall
impl Default for VerifierCall
Sourcefn default() -> VerifierCall
fn default() -> VerifierCall
Returns the “default value” for a type. Read more
Sourceimpl Display for VerifierCall
impl Display for VerifierCall
Sourceimpl EthCall for VerifierCall
impl EthCall for VerifierCall
Sourceimpl From<VerifierCall> for ProverCalls
impl From<VerifierCall> for ProverCalls
Sourcefn from(value: VerifierCall) -> Self
fn from(value: VerifierCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for VerifierCall
impl Hash for VerifierCall
Sourceimpl PartialEq for VerifierCall
impl PartialEq for VerifierCall
Sourceimpl Tokenizable for VerifierCall
impl Tokenizable for VerifierCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for VerifierCall
impl Eq for VerifierCall
impl StructuralPartialEq for VerifierCall
impl TokenizableItem for VerifierCall