pub struct VersionCall {
pub prover: Address,
}Expand description
Container type for all input parameters for the version function with signature version(address) and selector 0x767cb5bf
Fields
prover: AddressTrait Implementations
Sourceimpl AbiDecode for VersionCall
impl AbiDecode for VersionCall
Sourceimpl AbiEncode for VersionCall
impl AbiEncode for VersionCall
Sourceimpl AbiType for VersionCall
impl AbiType for VersionCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for VersionCall
impl Clone for VersionCall
Sourcefn clone(&self) -> VersionCall
fn clone(&self) -> VersionCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VersionCall
impl Debug for VersionCall
Sourceimpl Default for VersionCall
impl Default for VersionCall
Sourcefn default() -> VersionCall
fn default() -> VersionCall
Returns the “default value” for a type. Read more
Sourceimpl Display for VersionCall
impl Display for VersionCall
Sourceimpl EthCall for VersionCall
impl EthCall for VersionCall
Sourceimpl From<VersionCall> for ProverCalls
impl From<VersionCall> for ProverCalls
Sourcefn from(value: VersionCall) -> Self
fn from(value: VersionCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for VersionCall
impl Hash for VersionCall
Sourceimpl PartialEq for VersionCall
impl PartialEq for VersionCall
Sourceimpl Tokenizable for VersionCall
impl Tokenizable for VersionCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for VersionCall
impl Eq for VersionCall
impl StructuralPartialEq for VersionCall
impl TokenizableItem for VersionCall