pub struct VersionReturn(pub U256);Expand description
Container type for all return fields from the version function with signature version(address) and selector 0x767cb5bf
Tuple Fields
0: U256Trait Implementations
Sourceimpl AbiDecode for VersionReturn
impl AbiDecode for VersionReturn
Sourceimpl AbiEncode for VersionReturn
impl AbiEncode for VersionReturn
Sourceimpl AbiType for VersionReturn
impl AbiType for VersionReturn
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for VersionReturn
impl Clone for VersionReturn
Sourcefn clone(&self) -> VersionReturn
fn clone(&self) -> VersionReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VersionReturn
impl Debug for VersionReturn
Sourceimpl Default for VersionReturn
impl Default for VersionReturn
Sourcefn default() -> VersionReturn
fn default() -> VersionReturn
Returns the “default value” for a type. Read more
Sourceimpl Hash for VersionReturn
impl Hash for VersionReturn
Sourceimpl PartialEq for VersionReturn
impl PartialEq for VersionReturn
Sourceimpl Tokenizable for VersionReturn
impl Tokenizable for VersionReturn
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for VersionReturn
impl Eq for VersionReturn
impl StructuralPartialEq for VersionReturn
impl TokenizableItem for VersionReturn