pub struct AdjudicateCall {
pub tid: U256,
pub player_amount: U256,
pub miner_amount: U256,
pub slash: bool,
}Expand description
Container type for all input parameters for the adjudicate function with signature adjudicate(uint256,uint256,uint256,bool) and selector 0xd1553c1f
Fields
tid: U256player_amount: U256miner_amount: U256slash: boolTrait Implementations
Sourceimpl AbiDecode for AdjudicateCall
impl AbiDecode for AdjudicateCall
Sourceimpl AbiEncode for AdjudicateCall
impl AbiEncode for AdjudicateCall
Sourceimpl AbiType for AdjudicateCall
impl AbiType for AdjudicateCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for AdjudicateCall
impl Clone for AdjudicateCall
Sourcefn clone(&self) -> AdjudicateCall
fn clone(&self) -> AdjudicateCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdjudicateCall
impl Debug for AdjudicateCall
Sourceimpl Default for AdjudicateCall
impl Default for AdjudicateCall
Sourcefn default() -> AdjudicateCall
fn default() -> AdjudicateCall
Returns the “default value” for a type. Read more
Sourceimpl Display for AdjudicateCall
impl Display for AdjudicateCall
Sourceimpl EthCall for AdjudicateCall
impl EthCall for AdjudicateCall
Sourceimpl From<AdjudicateCall> for TaskCalls
impl From<AdjudicateCall> for TaskCalls
Sourcefn from(value: AdjudicateCall) -> Self
fn from(value: AdjudicateCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for AdjudicateCall
impl Hash for AdjudicateCall
Sourceimpl PartialEq for AdjudicateCall
impl PartialEq for AdjudicateCall
Sourceimpl Tokenizable for AdjudicateCall
impl Tokenizable for AdjudicateCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for AdjudicateCall
impl Eq for AdjudicateCall
impl StructuralPartialEq for AdjudicateCall
impl TokenizableItem for AdjudicateCall