pub struct AdjudicateTaskFilter {
pub id: U256,
pub sender: Address,
pub player_amount: U256,
pub miner_amount: U256,
pub dao_amount: U256,
pub slash: bool,
}Fields
id: U256sender: Addressplayer_amount: U256miner_amount: U256dao_amount: U256slash: boolTrait Implementations
Sourceimpl AbiType for AdjudicateTaskFilter
impl AbiType for AdjudicateTaskFilter
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for AdjudicateTaskFilter
impl Clone for AdjudicateTaskFilter
Sourcefn clone(&self) -> AdjudicateTaskFilter
fn clone(&self) -> AdjudicateTaskFilter
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdjudicateTaskFilter
impl Debug for AdjudicateTaskFilter
Sourceimpl Default for AdjudicateTaskFilter
impl Default for AdjudicateTaskFilter
Sourcefn default() -> AdjudicateTaskFilter
fn default() -> AdjudicateTaskFilter
Returns the “default value” for a type. Read more
Sourceimpl Display for AdjudicateTaskFilter
impl Display for AdjudicateTaskFilter
Sourceimpl EthEvent for AdjudicateTaskFilter
impl EthEvent for AdjudicateTaskFilter
Sourcefn signature() -> H256
fn signature() -> H256
Retrieves the signature for the event this data corresponds to.
This signature is the Keccak-256 hash of the ABI signature of
this event.
Sourcefn abi_signature() -> Cow<'static, str>
fn abi_signature() -> Cow<'static, str>
Retrieves the ABI signature for the event this data corresponds
to.
Sourcefn decode_log(log: &RawLog) -> Result<Self, Error>where
Self: Sized,
fn decode_log(log: &RawLog) -> Result<Self, Error>where
Self: Sized,
Decodes an Ethereum
RawLog into an instance of the type.Sourcefn is_anonymous() -> bool
fn is_anonymous() -> bool
Returns true if this is an anonymous event
Sourceimpl From<AdjudicateTaskFilter> for TaskEvents
impl From<AdjudicateTaskFilter> for TaskEvents
Sourcefn from(value: AdjudicateTaskFilter) -> Self
fn from(value: AdjudicateTaskFilter) -> Self
Converts to this type from the input type.
Sourceimpl Hash for AdjudicateTaskFilter
impl Hash for AdjudicateTaskFilter
Sourceimpl PartialEq for AdjudicateTaskFilter
impl PartialEq for AdjudicateTaskFilter
Sourceimpl Tokenizable for AdjudicateTaskFilter
impl Tokenizable for AdjudicateTaskFilter
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for AdjudicateTaskFilter
impl Eq for AdjudicateTaskFilter
impl StructuralPartialEq for AdjudicateTaskFilter
impl TokenizableItem for AdjudicateTaskFilter