pub struct DisputeCall {
pub tid: U256,
}Expand description
Container type for all input parameters for the dispute function with signature dispute(uint256) and selector 0x86d6282c
Fields
tid: U256Trait Implementations
Sourceimpl AbiDecode for DisputeCall
impl AbiDecode for DisputeCall
Sourceimpl AbiEncode for DisputeCall
impl AbiEncode for DisputeCall
Sourceimpl AbiType for DisputeCall
impl AbiType for DisputeCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for DisputeCall
impl Clone for DisputeCall
Sourcefn clone(&self) -> DisputeCall
fn clone(&self) -> DisputeCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DisputeCall
impl Debug for DisputeCall
Sourceimpl Default for DisputeCall
impl Default for DisputeCall
Sourcefn default() -> DisputeCall
fn default() -> DisputeCall
Returns the “default value” for a type. Read more
Sourceimpl Display for DisputeCall
impl Display for DisputeCall
Sourceimpl EthCall for DisputeCall
impl EthCall for DisputeCall
Sourceimpl From<DisputeCall> for TaskCalls
impl From<DisputeCall> for TaskCalls
Sourcefn from(value: DisputeCall) -> Self
fn from(value: DisputeCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for DisputeCall
impl Hash for DisputeCall
Sourceimpl PartialEq for DisputeCall
impl PartialEq for DisputeCall
Sourceimpl Tokenizable for DisputeCall
impl Tokenizable for DisputeCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for DisputeCall
impl Eq for DisputeCall
impl StructuralPartialEq for DisputeCall
impl TokenizableItem for DisputeCall