pub struct SubmitCall {
pub tid: U256,
pub proof: Bytes,
}Expand description
Container type for all input parameters for the submit function with signature submit(uint256,bytes) and selector 0xd1a2eab2
Fields
tid: U256proof: BytesTrait Implementations
Sourceimpl AbiDecode for SubmitCall
impl AbiDecode for SubmitCall
Sourceimpl AbiEncode for SubmitCall
impl AbiEncode for SubmitCall
Sourceimpl AbiType for SubmitCall
impl AbiType for SubmitCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for SubmitCall
impl Clone for SubmitCall
Sourcefn clone(&self) -> SubmitCall
fn clone(&self) -> SubmitCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubmitCall
impl Debug for SubmitCall
Sourceimpl Default for SubmitCall
impl Default for SubmitCall
Sourcefn default() -> SubmitCall
fn default() -> SubmitCall
Returns the “default value” for a type. Read more
Sourceimpl Display for SubmitCall
impl Display for SubmitCall
Sourceimpl EthCall for SubmitCall
impl EthCall for SubmitCall
Sourceimpl From<SubmitCall> for TaskCalls
impl From<SubmitCall> for TaskCalls
Sourcefn from(value: SubmitCall) -> Self
fn from(value: SubmitCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for SubmitCall
impl Hash for SubmitCall
Sourceimpl PartialEq for SubmitCall
impl PartialEq for SubmitCall
Sourceimpl Tokenizable for SubmitCall
impl Tokenizable for SubmitCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for SubmitCall
impl Eq for SubmitCall
impl StructuralPartialEq for SubmitCall
impl TokenizableItem for SubmitCall