pub struct TasksReturn {
pub status: u8,
pub prover: Address,
pub player: Address,
pub fee: U256,
pub miner: Address,
pub overtime: U256,
pub publics: Bytes,
pub dispute: U256,
}Expand description
Container type for all return fields from the tasks function with signature tasks(uint256) and selector 0x8d977672
Fields
status: u8prover: Addressplayer: Addressfee: U256miner: Addressovertime: U256publics: Bytesdispute: U256Trait Implementations
Sourceimpl AbiDecode for TasksReturn
impl AbiDecode for TasksReturn
Sourceimpl AbiEncode for TasksReturn
impl AbiEncode for TasksReturn
Sourceimpl AbiType for TasksReturn
impl AbiType for TasksReturn
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for TasksReturn
impl Clone for TasksReturn
Sourcefn clone(&self) -> TasksReturn
fn clone(&self) -> TasksReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TasksReturn
impl Debug for TasksReturn
Sourceimpl Default for TasksReturn
impl Default for TasksReturn
Sourcefn default() -> TasksReturn
fn default() -> TasksReturn
Returns the “default value” for a type. Read more
Sourceimpl Hash for TasksReturn
impl Hash for TasksReturn
Sourceimpl PartialEq for TasksReturn
impl PartialEq for TasksReturn
Sourceimpl Tokenizable for TasksReturn
impl Tokenizable for TasksReturn
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for TasksReturn
impl Eq for TasksReturn
impl StructuralPartialEq for TasksReturn
impl TokenizableItem for TasksReturn